Templates — Django Grappelli 2.4.8 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.4.8 documentation »

# Templates

New in version 2.4.

Grappelli includes a Documentation about the HTML/CSS framework.

If you’re using the default URL-pattern (see Quick start guide) you’ll find the documentation at:

    /grappelli/grp-doc/

Note

This is fairly new and will be improved with future releases.

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.4.8 documentation »